"""Definitions of quadrature rules."""

from quadraturerules.rules.gauss_legendre import gauss_legendre
from quadraturerules.rules.gauss_lobatto_legendre import gauss_lobatto_legendre
from quadraturerules.rules.hammer_marlowe_stroud import hammer_marlowe_stroud
from quadraturerules.rules.sauter_schwab import sauter_schwab
from quadraturerules.rules.xiao_gimbutas import xiao_gimbutas
from quadraturerules.rules.centroid_quadrature import centroid_quadrature
from quadraturerules.rules.vertex_quadrature import vertex_quadrature
